##

##

###

###

##

##

##

###

###

##

    	description

    		This is a module for organizing.

    	on
    		session 1
    			docker compose up -d; docker exec -it mediphy.1 bash -c "bash"
    			. /habitat/_controls/build_1.sh

    		session 2
    			 docker exec -it mediphy.1 bash -c "bash"
    			. /habitat/_controls/build_2.sh

    	off

    	constellation
    		tmux?

    		(cd /habitat/constellation && mediphy_1 ventures on)
    		(cd /habitat/parties/mediphy/frontiers/trends/sveltenetics && bun run dev)

    		[mongo] 192.168.0.98:39000
    		[sanic] 192.168.0.98:22000

    	monetary
    		objectives:
    			[ ] export the "passes", dump the "squeezes"

    		saving
    			mediphy_1 adventures monetary saves export --version 1

    		loading
    			mediphy_1 adventures monetary saves import --version 1 --drop

    	publish
    		(cd /habitat/parties/mediphy/frontiers/trends/sveltenetics && bun run build)
    		ls /habitat/parties/mediphy/frontiers/trends/sveltenetics/build

    		(cd /habitat/constellations && mediphy_1 ventures refresh)
    		python3 /habitat/parties/mediphy/_status/status.proc.py

    		pip install poetry
    		(cd /habitat && rm -rf dist && poetry build --format sdist --verbose && chmod -R 777 /habitat)
    		poetry publish --verbose;

    		chmod -R 777 /habitat